@@ -36,7 +36,7 @@ def check_complex_addon_entrypoint(report: Report, addon_path: str, parsed_xml,
                                          max_entrypoint_count)
                 else:
                     report.add(
-                        Record(PROBLEM, "%s Entry point does not exists" % library))
+                        Record(PROBLEM, f"{library} Entry point does not exists"))
 
 
 def _number_of_lines(report: Report, filepath: str, library: str, max_entrypoint_count: int):
@@ -53,19 +53,18 @@ def _number_of_lines(report: Report, filepath: str, library: str, max_entrypoint
         lineno = analyze(data).lloc
         if lineno >= max_entrypoint_count:
             report.add(Record(WARNING,
-                              "Complex entry point. Check: %s | Counted lines: %d | Lines allowed: %d"
-                              % (library, lineno, max_entrypoint_count)))
+                              f"Complex entry point. Check: {library} | "
+                              f"Counted lines: {lineno} | Lines allowed: {max_entrypoint_count}"))
 
     except UnicodeDecodeError as e:
-        report.add(Record(PROBLEM, "UnicodeDecodeError: {}".format(e)))
+        report.add(Record(PROBLEM, f"UnicodeDecodeError: {e}"))
 
     except SyntaxError as e:
         if e.msg == 'SyntaxError at line: 1':
             report.add(Record(PROBLEM,
-                              ("Error parsing file, is your file saved with UTF-8 encoding? "
-                               "Make sure it has no BOM. Check: %s")
-                              % library))
+                              (f"Error parsing file, is your file saved with UTF-8 encoding? "
+                               f"Make sure it has no BOM. Check: {library}")))
         else:
             report.add(Record(PROBLEM,
-                              "Error parsing file, is there a syntax error in your file? Check: %s"
-                              % library))
+                               "Error parsing file, is there a syntax error in your file?" \
+                               f"Check: {library}"))
